@@ -537,9 +537,9 @@ elsif ( $mailq eq "nullmailer" ) {
 	}
 
 	while (<MAILQ>) {
-	    #2006-06-22 16:00:00  282 bytes
+	    #2022-08-25 01:30:40 502 bytes from <user@example.com>
 
-	    if (/^[1-9][0-9]*-[01][0-9]-[0-3][0-9]\s[0-2][0-9]\:[0-5][0-9]\:[0-5][0-9]\s+[0-9]+\sbytes/) {
+	    if (/^\d{4}-\d{2}-\d{2}\s+\d{2}\:\d{2}\:\d{2}\s+\d+\sbytes/) {
 		$msg_q++ ;
 	    }
 	}
