@@ -1354,10 +1354,10 @@ int process_arguments(int argc, char **argv) {
 			usage5 ();
 			case 'h': /* help */
 				print_help();
-				exit(STATE_OK);
+				exit(STATE_UNKNOWN);
 			case 'V': /* version */
 				print_revision(progname, NP_VERSION);
-				exit(STATE_OK);
+				exit(STATE_UNKNOWN);
 			case 'H': /* hostname */
 				server_address=optarg;
 				break;
